@@ -109,7 +109,7 @@ async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_on
     unique_item = params[0] if params else params
     try:
         logging.debug(f"Fetching transaction for signature={unique_item}")
-        response = await makeLimitedRpcCall(method=method, params=params,
+        response = await async_make_rate_limited_call(method=method, params=params,
                                             url_1_only=url_1_only,
                                             url_2_only=url_2_only,
                                             **kwargs)
@@ -125,7 +125,7 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     After the 1st attempt, set url_1_only=False.
     """
     ogsettings = kwargs.get('solcatcherSettings',{})
-    solcatcherSettings={"getStatusCode":True}
+    solcatcherSettings=defaultSolcatcherSettings
     solcatcherSettings.update(ogsettings)
     kwargs['solcatcherSettings']=solcatcherSettings
     kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
