@@ -14,15 +14,15 @@ def getSolcatcherTsUrl(endpoint=None):
 def getSolcatcherDbCalls(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/dbCalls")
 def get_response(response):
-    if isinstance(response,requests.Response):
+    if isinstance(response,requests.Response) or isinstance(response,httpx.Response):
+      try:
+        response = response.json()
+      except:
         try:
-            response = response.json()
+          response = response.text
         except:
-          try:
-            response = response.text
-          except:
-            pass
-    return response
+          pass
+      return response
 def get_result(response,key='result'):
     response = get_response(response)
     if isinstance(response,dict):
